@@ -1,6 +1,6 @@
 import numpy as np
 from mpl_toolkits.axes_grid1 import make_axes_locatable
-from .format import layout_fig
+from .format import layout_fig, labelfigs
 from matplotlib import pyplot as plt
 
 
@@ -45,7 +45,7 @@ def embedding_maps(data, image, colorbar_shown=True,
                 im.set_clim(c_lim)
 
         if fig_labels is not None:
-            format.labelfigs(ax, i, size=18)
+            labelfigs(ax, i, size=18)
 
     if title is not None:
         # Adds title to the figure
